@@ -11,6 +11,7 @@ from geopy.distance import geodesic
 from traveltimemap.tasks import *
 
 
+
 def get_timestamp(df):
     """
     Get the dataframe with timestamps and return a map with permanent timestamps
@@ -27,7 +28,7 @@ def get_timestamp(df):
     feature = folium.FeatureGroup(name="Travel Time Map with Permanent Stamps")
 
     # change map center with the avg of the data
-    map = folium.Map([data.Lat.mean(), data.Long.mean()], zoom_start=12)
+    map = folium.Map([data.Lat.mean(), data.Long.mean()], zoom_start=12, tiles='https://{s}.basemaps.cartocdn.com/rastertiles/voyager/{z}/{x}/{y}{r}.png', attr='CartoDB.Voyager')
 
     # add a marker for each point
     for lt, ln, s, t, dt in zip(lat, long, speed, date, date2):
@@ -37,7 +38,7 @@ def get_timestamp(df):
 
     # call for legend
     map = create_legend(map, 'Speed - MPH',
-                        colors=['red', 'orange', 'yellow', '#98ebb0'],
+                        colors=['red', 'orange', 'yellow', '#60f250'],
                         labels=['0-20', '21-40', '41-55', '55+'])
 
     # time stats
